==> github-com-ant-design-ant-design-3.13.5.jar: META-INF/resources/webjars/github-com-ant-design-ant-design/3.13.5/spec/download.zh-CN.md <==
---
category: 其他
order: 0
title: 设计资源
---

这里提供 Ant Design 相关设计资源和设计工具的下载，更多设计资源正在整理和完善中。

- 新版本 Sketch Symbols 组件反馈地址：[🦜 反馈地址](https://www.yuque.com/kitchen/topics/51)

<div class="resource-cards">
  <a target="_blank" href="https://github.com/ant-design/ant-design/releases/download/resource/Ant.Design.Components.3.12.0.sketch" class="resource-card">
    <div class="resource-card-icon">
      <img width="65" src="https://gw.alipayobjects.com/zos/rmsportal/pKfDZnzocrbAOSzDQOQq.png">
    </div>
    <div class="resource-card-content">
      <span class="resource-card-title">
        全新 Sketch 组件包
        <span class="resource-card-hot-badge">NEW</span>
      </span>
      <span class="resource-card-description">桌面组件 Sketch 模板包</span>
    </div>
  </a>
  <a target="_blank" href="http://p.tb.cn/rmsportal_3436_AntDesignMobile_20Template_20V1.0.sketch" class="resource-card">
    <div class="resource-card-icon">
      <img width="41" src="https://gw.alipayobjects.com/zos/rmsportal/rFMdPVzabtQwxONUuVFr.png">
    </div>
    <div class="resource-card-content">
      <span class="resource-card-title">Mobile Components</span>
      <span class="resource-card-description">移动组件 Sketch 模板</span>
    </div>
  </a>
  <a target="_blank" href="https://github.com/ant-design/ant-design/releases/download/resource/Ant.Design.Pro.sketch" class="resource-card">
    <div class="resource-card-icon">
      <img width="65" src="https://gw.alipayobjects.com/zos/rmsportal/ibCZMxKsTUzDbwTEdcTC.svg">
    </div>
    <div class="resource-card-content">
      <span class="resource-card-title">Ant Design Pro</span>
      <span class="resource-card-description">典型页面 + 通用业务模板</span>
    </div>
  </a>
  <a target="_blank" href="http://library.ant.design" class="resource-card">
    <div class="resource-card-icon">
      <img width="50" src="https://gw.alipayobjects.com/zos/rmsportal/TXrKQUJBTuwSTGimGYYn.png">
    </div>
    <div class="resource-card-content">
      <span class="resource-card-title">Ant Design Library</span>
      <span class="resource-card-description">一套强大的 Ant Design 的 Axure 部件库</span>
    </div>
  </a>
  <a target="_blank" href="http://kitchen.alipay.com" class="resource-card">
    <div class="resource-card-icon">
      <img width="65" src="https://gw.alipayobjects.com/zos/rmsportal/ATYZYtJhchhONKObIwXT.png">
    </div>
    <div class="resource-card-content">
      <span class="resource-card-title">
        Kitchen
        <span class="resource-card-hot-badge">HOT</span>
      </span>
      <span class="resource-card-description">Sketch 工具集</span>
    </div>
  </a>
  <a target="_blank" href="https://landing.ant.design/docs/download-cn" class="resource-card">
    <div class="resource-card-icon">
      <img width="65" src="https://gw.alipayobjects.com/zos/rmsportal/EAHlyTmYeDtTkZIPbUnP.svg">
    </div>
    <div class="resource-card-content">
      <span class="resource-card-title">
        Ant Design Landing
        <span class="resource-card-hot-badge">NEW</span>
      </span>
      <span class="resource-card-description">首页模板集</span>
    </div>
  </a>
  <a target="_blank" href="http://ux.ant.design" class="resource-card">
    <div class="resource-card-icon">
      <img width="64" src="https://gw.alipayobjects.com/zos/rmsportal/yMULSUQQyhoEGrCXlovN.png">
    </div>
    <div class="resource-card-content">
      <span class="resource-card-title">Ant UX</span>
      <span class="resource-card-description">一套页面逻辑原型库，帮你梳理页面逻辑</span>
    </div>
  </a>
  <a target="_blank" href="https://www.xiaopiu.com/topic/ant-design" class="resource-card">
    <div class="resource-card-icon">
      <img width="72" src="https://img.xiaopiu.com/userImages/img753167822272f8.png">
    </div>
    <div class="resource-card-content">
      <span class="resource-card-title">Ant Design 原型（xiaopiu）</span>
      <span class="resource-card-description">可在线编辑的 Ant Design 组件库和交互原型</span>
    </div>
  </a>
</div>

==> github-com-ant-design-ant-design-3.21.4.jar: META-INF/resources/webjars/github-com-ant-design-ant-design/3.21.4/spec/download.zh-CN.md <==
---
category: 其他
order: 0
title: 设计资源
---

这里提供 Ant Design 相关设计资源和设计工具的下载，更多设计资源正在整理和完善中。

- 新版本 Sketch Symbols 组件反馈地址：[🦜 反馈地址](https://www.yuque.com/kitchen/topics/51)

<div class="resource-cards">
  <a target="_blank" href="https://github.com/ant-design/ant-design/releases/download/resource/Ant.Design.Components.3.12.0.sketch" class="resource-card">
    <div class="resource-card-icon">
      <img width="65" src="https://gw.alipayobjects.com/zos/rmsportal/pKfDZnzocrbAOSzDQOQq.png">
    </div>
    <div class="resource-card-content">
      <span class="resource-card-title">
        全新 Sketch 组件包
      </span>
      <span class="resource-card-description">桌面组件 Sketch 模板包</span>
    </div>
  </a>
  <a target="_blank" href="http://p.tb.cn/rmsportal_3436_AntDesignMobile_20Template_20V1.0.sketch" class="resource-card">
    <div class="resource-card-icon">
      <img width="41" src="https://gw.alipayobjects.com/zos/rmsportal/rFMdPVzabtQwxONUuVFr.png">
    </div>
    <div class="resource-card-content">
      <span class="resource-card-title">Mobile Components</span>
      <span class="resource-card-description">移动组件 Sketch 模板</span>
    </div>
  </a>
  <a target="_blank" href="https://github.com/ant-design/ant-design/releases/download/resource/Ant.Design.Pro.sketch" class="resource-card">
    <div class="resource-card-icon">
      <img width="65" src="https://gw.alipayobjects.com/zos/rmsportal/ibCZMxKsTUzDbwTEdcTC.svg">
    </div>
    <div class="resource-card-content">
      <span class="resource-card-title">Ant Design Pro</span>
      <span class="resource-card-description">典型页面 + 通用业务模板</span>
    </div>
  </a>
  <a target="_blank" href="http://library.ant.design" class="resource-card">
    <div class="resource-card-icon">
      <img width="50" src="https://gw.alipayobjects.com/zos/rmsportal/TXrKQUJBTuwSTGimGYYn.png">
    </div>
    <div class="resource-card-content">
      <span class="resource-card-title">Ant Design Library</span>
      <span class="resource-card-description">一套强大的 Ant Design 的 Axure 部件库</span>
    </div>
  </a>
  <a target="_blank" href="http://kitchen.alipay.com" class="resource-card">
    <div class="resource-card-icon">
      <img width="65" src="https://gw.alipayobjects.com/zos/rmsportal/ATYZYtJhchhONKObIwXT.png">
    </div>
    <div class="resource-card-content">
      <span class="resource-card-title">
        Kitchen
        <span class="resource-card-hot-badge">HOT</span>
      </span>
      <span class="resource-card-description">Sketch 工具集</span>
    </div>
  </a>
  <a target="_blank" href="https://landing.ant.design/docs/download-cn" class="resource-card">
    <div class="resource-card-icon">
      <img width="65" src="https://gw.alipayobjects.com/zos/rmsportal/EAHlyTmYeDtTkZIPbUnP.svg">
    </div>
    <div class="resource-card-content">
      <span class="resource-card-title">
        Ant Design Landing
      </span>
      <span class="resource-card-description">首页模板集</span>
    </div>
  </a>
  <a target="_blank" href="http://ux.ant.design" class="resource-card">
    <div class="resource-card-icon">
      <img width="64" src="https://gw.alipayobjects.com/zos/rmsportal/yMULSUQQyhoEGrCXlovN.png">
    </div>
    <div class="resource-card-content">
      <span class="resource-card-title">Ant UX</span>
      <span class="resource-card-description">一套页面逻辑原型库，帮你梳理页面逻辑</span>
    </div>
  </a>
  <a target="_blank" href="https://www.xiaopiu.com/topic/ant-design" class="resource-card">
    <div class="resource-card-icon">
      <img width="72" src="https://img.xiaopiu.com/userImages/img753167822272f8.png">
    </div>
    <div class="resource-card-content">
      <span class="resource-card-title">Ant Design 原型（xiaopiu）</span>
      <span class="resource-card-description">可在线编辑的 Ant Design 组件库和交互原型</span>
    </div>
  </a>
  <a target="_blank" href="https://www.antforfigma.com" class="resource-card">
    <div class="resource-card-icon">
      <img width="65" src="https://antforfigma.com/images/antforfigma-icon.png">
    </div>
    <div class="resource-card-content">
      <span class="resource-card-title">
        Figma 组件包
        <span class="resource-card-hot-badge">NEW</span>
      </span>
      <span class="resource-card-description">在 Figma 使用 Ant Design 进行设计</span>
    </div>
  </a>
</div>
